downloadNEONFile: Download a file from the NEON API

View source: R/downloadNEONFile.R

downloadNEONFileR Documentation

Download a file from the NEON API

Description

Download a file via the NEON API, using a token as necessary.

Usage

downloadNEONFile(url, outpath, useragent, token)

Arguments

url

The url pointing to the file to be downloaded

outpath

The file path to save the file to

useragent

The user agent to send to the API

token

The user's API token

Value

A status message indicating whether the download was successful or not

Author(s)

Claire Lunch clunch@battelleecology.org

References

License: GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007


neonUtilities documentation built on Sept. 10, 2026, 1:06 a.m.