schemaAllStringsDuck: Create a duckdb schema with every variable coded as a string...

View source: R/schemaAllStringsDuck.R

schemaAllStringsDuckR Documentation

Create a duckdb schema with every variable coded as a string field.

Description

Use the field names in a NEON variables file to create a duckdb schema of all strings, or, if no variables file is available, read the header and assign everything as string.

Usage

schemaAllStringsDuck(variables, listOrSchema = "schema")

Arguments

variables

A data frame containing a NEON variables file for a single table, or a set of field names.

listOrSchema

Should the variable set be returned as a list of names and types, or a pasted schema?

Value

A duckdb schema for the relevant data table with all variables set to string.

Author(s)

Claire Lunch clunch@battelleecology.org

References

License: GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007


neonUtilities documentation built on Sept. 10, 2026, 1:06 a.m.