schemaFromVarDuck: Create a duckdb schema from a NEON variables file.

View source: R/schemaFromVarDuck.R

schemaFromVarDuckR Documentation

Create a duckdb schema from a NEON variables file.

Description

Use the field names and data types in a NEON variables file to create a duckdb schema.

Usage

schemaFromVarDuck(variables, tab, package)

Arguments

variables

A data frame containing a NEON variables file, or a url pointing to a NEON variables file.

tab

The name of the table to generate a schema from.

package

Should the schema be created for the basic or expanded package?

Value

A duckdb schema for the relevant data table.

Author(s)

Claire Lunch clunch@battelleecology.org

References

License: GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007


neonUtilities documentation built on Sept. 10, 2026, 1:06 a.m.