stackDataFilesArrow: Join data files in a unzipped NEON data package by table type

View source: R/stackDataFilesArrow.R

stackDataFilesArrowR Documentation

Join data files in a unzipped NEON data package by table type

Description

Given a folder of unzipped files (unzipped NEON data file), do a full join of all data files, grouped by table type. This should result in a small number of large files.

Usage

stackDataFilesArrow(
  folder,
  cloud.mode = FALSE,
  progress = TRUE,
  all.string = FALSE,
  dpID
)

Arguments

folder

The location of the data

cloud.mode

T or F, are data transferred from one cloud environment to another? If T, this function returns a list of url paths to data files.

progress

T or F, should progress bars and messages be printed?

all.string

T or F, should all fields be set to data type = string? Ignored unless cloud.mode=TRUE. Defaults to FALSE; should generally only be used if schema from variables file is failing and inferring the schema is introducing errors.

dpID

The data product identifier

Value

One file for each table type is created and written.

Author(s)

Christine Laney claney@battelleecology.org Claire Lunch clunch@battelleecology.org

References

License: GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007


neonUtilities documentation built on Sept. 10, 2026, 1:06 a.m.