View source: R/stackDataFilesDuck.R
| stackDataFilesDuck | R Documentation |
Takes a set of paths pointing to data files and a variables file and attempts to unify them into a duckdb dataset.
stackDataFilesDuck(urls, varset, tabl, package, all.string = FALSE)
urls |
The set of urls to be combined into a dataset. |
varset |
A list of urls pointing to the set of variables files relevant to the url set. |
tabl |
The table name of the table the url set represents. |
package |
Basic or expanded data package? |
all.string |
T or F, should all fields be set to data type = string? Defaults to FALSE; should generally only be used if schema from variables file is failing and inferring the schema is introducing errors. |
A duckdb dataset for the input data paths.
Claire Lunch clunch@battelleecology.org
License: GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.