- filepath
The location of the NEON data containing URIs. Can be either a local directory containing NEON tabular data or a list object containing tabular data.
- savepath
The location to save the output files from the ECS bucket, optional.
Defaults to creating a "ECS_zipFiles" folder in the filepath directory.
- pick.files
T or F, should the user be told the name of each file before downloading?
Defaults to F. When working in batch mode, or other non-interactive workflow, use pick.files=F.
- check.size
T or F, should the user be told the total file size before downloading?
Defaults to T. When working in batch mode, or other non-interactive workflow, use check.size=F.
- unzip
T or F, indicates if the downloaded zip files from ECS buckets should be
unzipped into the same directory, defaults to T. Supports .zip and .tar.gz files currently.
- saveZippedFiles
T or F: should the zip files be retained after unzipping? Defaults to F.