View source: R/downloadNEONFile.R
| downloadNEONFile | R Documentation |
Download a file via the NEON API, using a token as necessary.
downloadNEONFile(url, outpath, useragent, token)
url |
The url pointing to the file to be downloaded |
outpath |
The file path to save the file to |
useragent |
The user agent to send to the API |
token |
The user's API token |
A status message indicating whether the download was successful or not
Claire Lunch clunch@battelleecology.org
License: GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.