downloadNEONFile: Download a file from the NEON API
Description
Download a file via the NEON API, using a token as necessary.
Usage
downloadNEONFile(url, outpath, useragent, token)
Value
A status message indicating whether the download was successful or not
Arguments
- url
The url pointing to the file to be downloaded
- outpath
The file path to save the file to
- useragent
The user agent to send to the API
- token
The user's API token
References
License: GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007