View source: R/schemaAllStringsDuck.R
| schemaAllStringsDuck | R Documentation |
Use the field names in a NEON variables file to create a duckdb schema of all strings, or, if no variables file is available, read the header and assign everything as string.
schemaAllStringsDuck(variables, listOrSchema = "schema")
variables |
A data frame containing a NEON variables file for a single table, or a set of field names. |
listOrSchema |
Should the variable set be returned as a list of names and types, or a pasted schema? |
A duckdb schema for the relevant data table with all variables set to string.
Claire Lunch clunch@battelleecology.org
License: GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.