Learn R Programming

neonUtilities (version 4.0.2)

schemaAllStringsDuck: Create a duckdb schema with every variable coded as a string field.

Description

Use the field names in a NEON variables file to create a duckdb schema of all strings, or, if no variables file is available, read the header and assign everything as string.

Usage

schemaAllStringsDuck(variables, listOrSchema = "schema")

Value

A duckdb schema for the relevant data table with all variables set to string.

Arguments

variables

A data frame containing a NEON variables file for a single table, or a set of field names.

listOrSchema

Should the variable set be returned as a list of names and types, or a pasted schema?

Author

Claire Lunch clunch@battelleecology.org

References

License: GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007