Use the field names in a NEON variables file to create a duckdb schema of all strings, or, if no variables file is available, read the header and assign everything as string.
schemaAllStringsDuck(variables, listOrSchema = "schema")A duckdb schema for the relevant data table with all variables set to string.
A data frame containing a NEON variables file for a single table, or a set of field names.
Should the variable set be returned as a list of names and types, or a pasted schema?
Claire Lunch clunch@battelleecology.org
License: GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007