View source: R/schemaFromVarDuck.R
| schemaFromVarDuck | R Documentation |
Use the field names and data types in a NEON variables file to create a duckdb schema.
schemaFromVarDuck(variables, tab, package)
variables |
A data frame containing a NEON variables file, or a url pointing to a NEON variables file. |
tab |
The name of the table to generate a schema from. |
package |
Should the schema be created for the basic or expanded package? |
A duckdb schema for the relevant data table.
Claire Lunch clunch@battelleecology.org
License: GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.