Use the field names and data types in a NEON variables file to create a duckdb schema.
schemaFromVarDuck(variables, tab, package)A duckdb schema for the relevant data table.
A data frame containing a NEON variables file, or a url pointing to a NEON variables file.
The name of the table to generate a schema from.
Should the schema be created for the basic or expanded package?
Claire Lunch clunch@battelleecology.org
License: GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007