Given a folder of unzipped files (unzipped NEON data file), do a full join of all data files, grouped by table type. This should result in a small number of large files.
stackDataFilesArrow(
folder,
cloud.mode = FALSE,
progress = TRUE,
all.string = FALSE,
dpID
)One file for each table type is created and written.
The location of the data
T or F, are data transferred from one cloud environment to another? If T, this function returns a list of url paths to data files.
T or F, should progress bars and messages be printed?
T or F, should all fields be set to data type = string? Ignored unless cloud.mode=TRUE. Defaults to FALSE; should generally only be used if schema from variables file is failing and inferring the schema is introducing errors.
The data product identifier
Christine Laney claney@battelleecology.org Claire Lunch clunch@battelleecology.org
License: GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007